pub struct VarAllocator<T> { /* private fields */ }Expand description
Allocator for field variables.
Creates a new wire identifier when requested, and keeps tracks of the wires that have been declared as public.
Implementations
Sourceimpl<T: Clone + Unit> VarAllocator<T>
impl<T: Clone + Unit> VarAllocator<T>
pub fn new() -> Self
pub fn new_field_var(&self) -> FieldVar
pub fn allocate_vars<const N: usize>(&self) -> [FieldVar; N]
pub fn allocate_vars_vec(&self, count: usize) -> Vec<FieldVar>
pub fn allocate_public<const N: usize>( &self, public_values: &[T; N], ) -> [FieldVar; N]
pub fn allocate_public_vec(&self, public_values: &[T]) -> Vec<FieldVar>
pub fn vars_count(&self) -> usize
pub fn set_public_var(&self, val: FieldVar, var: T)
pub fn set_public_vars<Val, Var>( &self, vars: impl IntoIterator<Item = Var>, vals: impl IntoIterator<Item = Val>, )
pub fn public_vars(&self) -> Vec<(FieldVar, T)>